CA22-Cl01
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Audio |
clickAndWait | link=Añadir audio file |
type | id_name | Audio CA22-Cl01
select | id_status | label=Publicado
type | id_file | C:\Documents and Settings\mrivera\Escritorio\Merengue\test-data\test-audio.mp3
clickAndWait | _save |
verifyTextPresent | Audio CA19-Cl01 |
verifyText | link=Audio CA19-Cl01 | Audio CA19-Cl01
clickAndWait | link=Audio CA19-Cl01 |
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |